summary refs log tree commit diff
path: root/gnu/packages/commencement.scm
diff options
context:
space:
mode:
authorJan Nieuwenhuizen <janneke@gnu.org>2018-09-09 13:33:41 +0200
committerJan Nieuwenhuizen <janneke@gnu.org>2018-09-23 09:46:25 +0200
commitc362904485d3c8c3f155538ab2f7cd082b334801 (patch)
tree93702819befb58dee954d62067aa5b9cfadd7d7f /gnu/packages/commencement.scm
parenta2b2070b679ff7e92d856c7d6775f5f67ce4792d (diff)
downloadguix-c362904485d3c8c3f155538ab2f7cd082b334801.tar.gz
bootstrap: %bootstrap-inputs+toolchain: Replace %bootstrap-inputs.
* gnu/packages/commencement.scm (%bootstrap-inputs+toolchain): : New procedure
replacing %bootstrap-inputs to prepare for Mes bootstrap.  Update users.
* tests/union.scm (%bootstrap-inputs): New variable: set to
%bootstrap-inputs+toolchain.
Diffstat (limited to 'gnu/packages/commencement.scm')
-rw-r--r--gnu/packages/commencement.scm19
1 files changed, 11 insertions, 8 deletions
diff --git a/gnu/packages/commencement.scm b/gnu/packages/commencement.scm
index a4e71b000b..12d5b528fd 100644
--- a/gnu/packages/commencement.scm
+++ b/gnu/packages/commencement.scm
@@ -79,6 +79,9 @@
 ;;;
 ;;; Code:
 
+(define (%bootstrap-inputs+toolchain)
+  (%bootstrap-inputs))
+
 (define gnu-make-boot0
   (package-with-bootstrap-guile
    (package (inherit gnu-make)
@@ -101,13 +104,13 @@
                       (install-file "make" bin)
                       #t))))))))
      (native-inputs '())                          ; no need for 'pkg-config'
-     (inputs (%bootstrap-inputs)))))
+     (inputs (%bootstrap-inputs+toolchain)))))
 
 (define diffutils-boot0
   (package-with-bootstrap-guile
    (let ((p (package-with-explicit-inputs diffutils
                                           `(("make" ,gnu-make-boot0)
-                                            ,@(%bootstrap-inputs))
+                                            ,@(%bootstrap-inputs+toolchain))
                                           #:guile %bootstrap-guile)))
      (package (inherit p)
        (name "diffutils-boot0")
@@ -121,7 +124,7 @@
                                    (name "findutils-boot0"))
                                  `(("make" ,gnu-make-boot0)
                                    ("diffutils" ,diffutils-boot0) ; for tests
-                                   ,@(%bootstrap-inputs))
+                                   ,@(%bootstrap-inputs+toolchain))
                                  (current-source-location)
                                  #:guile %bootstrap-guile)))
 
@@ -131,17 +134,16 @@
                                    (inherit file)
                                    (name "file-boot0"))
                                  `(("make" ,gnu-make-boot0)
-                                   ,@(%bootstrap-inputs))
+                                   ,@(%bootstrap-inputs+toolchain))
                                  (current-source-location)
                                  #:guile %bootstrap-guile)))
 
-
 (define (%boot0-inputs)
   `(("make" ,gnu-make-boot0)
     ("diffutils" ,diffutils-boot0)
     ("findutils" ,findutils-boot0)
     ("file" ,file-boot0)
-    ,@(%bootstrap-inputs)))
+    ,@(%bootstrap-inputs+toolchain)))
 
 (define* (boot-triplet #:optional (system (%current-system)))
   ;; Return the triplet used to create the cross toolchain needed in the
@@ -150,8 +152,9 @@
 
 ;; Following Linux From Scratch, build a cross-toolchain in stage 0.  That
 ;; toolchain actually targets the same OS and arch, but it has the advantage
 ;; of being independent of the libc and tools in (%BOOTSTRAP-INPUTS), since
 ;; GCC-BOOT0 (below) is built without any reference to the target libc.
 
 (define binutils-boot0
   (package-with-bootstrap-guile
@@ -150,8 +152,9 @@
 ;; Following Linux From Scratch, build a cross-toolchain in stage 0.  That
 ;; toolchain actually targets the same OS and arch, but it has the advantage
-;; of being independent of the libc and tools in (%BOOTSTRAP-INPUTS), since
-;; GCC-BOOT0 (below) is built without any reference to the target libc.
+;; of being independent of the libc and tools in
+;; (%BOOTSTRAP-INPUTS+TOOLCHAIN), since GCC-BOOT0 (below) is built without any
+;; reference to the target libc.
 
 (define binutils-boot0